aboutsummaryrefslogtreecommitdiff
path: root/src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt
diff options
context:
space:
mode:
authorRobert Jaros <rjaros@finn.pl>2018-03-11 23:36:01 +0100
committerRobert Jaros <rjaros@finn.pl>2018-03-11 23:45:06 +0100
commitc0fca9901a634d53d8ee0bfb119b9b2e2f017d83 (patch)
tree127bbc1cd56097694d906d9b9245164436457a76 /src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt
parent3577c10b5c3839a06f64cb19e72788401bd7406d (diff)
downloadkvision-c0fca9901a634d53d8ee0bfb119b9b2e2f017d83.tar.gz
kvision-c0fca9901a634d53d8ee0bfb119b9b2e2f017d83.tar.bz2
kvision-c0fca9901a634d53d8ee0bfb119b9b2e2f017d83.zip
Change the name of content property in Tag component.
Diffstat (limited to 'src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt')
-rw-r--r--src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt b/src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt
index db9aebc5..9ec3d8ae 100644
--- a/src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt
+++ b/src/main/kotlin/pl/treksoft/kvision/form/HelpBlock.kt
@@ -28,10 +28,10 @@ import pl.treksoft.kvision.html.Tag
* Helper class for Bootstrap help block element.
*
* @constructor
* @param text the text of the label
* @param rich determines if [text] can contain HTML code
*/
-open class HelpBlock(text: String? = null, rich: Boolean = false) : Tag(
- TAG.SPAN, text, rich,
+open class HelpBlock(content: String? = null, rich: Boolean = false) : Tag(
+ TAG.SPAN, content, rich,
classes = setOf("help-block", "small")
)
@@ -28,10 +28,10 @@ import pl.treksoft.kvision.html.Tag
*
* @constructor
- * @param text the text of the label
- * @param rich determines if [text] can contain HTML code
+ * @param content the text of the label
+ * @param rich determines if [content] can contain HTML code
*/